CSS Coding Standards
--------------------

(Draft, to be continued)

:Naming: camelCase

Indentation rules
~~~~~~~~~~~~~~~~~
- 2 espaces avant les propriétés

- pas d'espace avant les ":", un espace après

- 1 seul espace entre les différentes valeurs pour une même propriété


Documentation
~~~~~~~~~~~~~
Please keep rules semantically linked grouped together, with a comment about
what they are for.

Recommendation
~~~~~~~~~~~~~~
- Try to use existing classes rather than introduce new ones

- Keep things as simple as possible while in the framework

- Think about later customization by application

- Avoid introducing a new CSS file for a few lines of CSS, at least while the
  framework doesn't include packing functionalities


